==> joda-convert_1.2.orig.tar.gz: joda-convert-1.2/src/test/java/org/joda/convert/DistanceTwoFromStringMethodAnnotations.java <==
/*
 *  Copyright 2010 Stephen Colebourne
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.joda.convert;

/**
 * Example class with no annotations.
 */
public class DistanceTwoFromStringMethodAnnotations {

    /** Amount. */
    final int amount;

    public DistanceTwoFromStringMethodAnnotations(int amount) {
        this.amount = amount;
    }

    @FromString
    public static DistanceTwoFromStringMethodAnnotations parse(String amount) {
        amount = amount.substring(0, amount.length() - 1);
        return new DistanceTwoFromStringMethodAnnotations(Integer.parseInt(amount));
    }

    @FromString
    public static DistanceTwoFromStringMethodAnnotations parse2(String amount) {
        amount = amount.substring(0, amount.length() - 1);
        return new DistanceTwoFromStringMethodAnnotations(Integer.parseInt(amount));
    }

    public DistanceTwoFromStringMethodAnnotations(String amount) {
        amount = amount.substring(0, amount.length() - 1);
        this.amount = Integer.parseInt(amount);
    }

    @ToString
    public String print() {
        return amount + "m";
    }

    @Override
    public String toString() {
        return "Distance[" + amount + "m]";
    }

}

==> joda-convert-2.2.4.tar.gz: joda-convert-2.2.4/src/test/java/org/joda/convert/DistanceTwoFromStringMethodAnnotations.java <==
/*
 *  Copyright 2010-present Stephen Colebourne
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package org.joda.convert;

/**
 * Example class with no annotations.
 */
public class DistanceTwoFromStringMethodAnnotations {

    /** Amount. */
    final int amount;

    public DistanceTwoFromStringMethodAnnotations(int amount) {
        this.amount = amount;
    }

    @FromString
    public static DistanceTwoFromStringMethodAnnotations parse(String amount) {
        String amt = amount.substring(0, amount.length() - 1);
        return new DistanceTwoFromStringMethodAnnotations(Integer.parseInt(amt));
    }

    @FromString
    public static DistanceTwoFromStringMethodAnnotations parse2(String amount) {
        String amt = amount.substring(0, amount.length() - 1);
        return new DistanceTwoFromStringMethodAnnotations(Integer.parseInt(amt));
    }

    public DistanceTwoFromStringMethodAnnotations(String amount) {
        String amt = amount.substring(0, amount.length() - 1);
        this.amount = Integer.parseInt(amt);
    }

    @ToString
    public String print() {
        return amount + "m";
    }

    @Override
    public String toString() {
        return "Distance[" + amount + "m]";
    }

}
